import { BatchWriteItemCommand, DynamoDBClient, } from "@aws-sdk/client-dynamodb";
import { readFileSync } from "fs";
import { getDynamoBatchWriteCommandConcurrency, MAX_DYNAMO_BATCH_WRITE_ITEM_COUNT, } from "./constants.js";
import { chunk } from "./util.js";
const PHYSICAL_RESOURCE_ID = "dynamodb-cache";
const dynamoClient = new DynamoDBClient({});
export async function handler(event) {
    switch (event.RequestType) {
        case "Create":
        case "Update":
            return insert();
        case "Delete":
            return remove();
    }
}
async function insert() {
    const tableName = process.env.CACHE_DYNAMO_TABLE;
    const file = readFileSync(`dynamodb-cache.json`, "utf8");
    const data = JSON.parse(file);
    const dataChunks = chunk(data, MAX_DYNAMO_BATCH_WRITE_ITEM_COUNT);
    const batchWriteParamsArray = dataChunks.map((chunk) => {
        return {
            RequestItems: {
                [tableName]: chunk.map((item) => ({
                    PutRequest: {
                        Item: item,
                    },
                })),
            },
        };
    });
    const paramsChunks = chunk(batchWriteParamsArray, getDynamoBatchWriteCommandConcurrency());
    for (const paramsChunk of paramsChunks) {
        await Promise.all(paramsChunk.map((params) => dynamoClient.send(new BatchWriteItemCommand(params))));
    }
    return {
        PhysicalResourceId: PHYSICAL_RESOURCE_ID,
        Data: {},
    };
}
async function remove() {
    // Do we want to actually delete anything here?
    return {
        PhysicalResourceId: PHYSICAL_RESOURCE_ID,
        Data: {},
    };
}
